@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,12 +7,11 @@
 #include "newmailnotifierattribute.h"
 
 #include <QByteArray>
-#include <QIODevice>
 #include <QDataStream>
+#include <QIODevice>
 
 namespace Akonadi
 {
-
 class NewMailNotifierAttributePrivate
 {
 public:
@@ -28,7 +27,7 @@ NewMailNotifierAttribute::~NewMailNotifierAttribute() = default;
 
 NewMailNotifierAttribute *NewMailNotifierAttribute::clone() const
 {
-    auto *attr = new NewMailNotifierAttribute();
+    auto attr = new NewMailNotifierAttribute();
     attr->setIgnoreNewMail(ignoreNewMail());
     return attr;
 }
